@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Lockout Plugin
-  * Copyright (c) 2004-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003-2010 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -83,9 +83,9 @@ function lockout_configtest_do()
    }
    global $activate_CAPTCHA_after_failed_attempts;
    if (!empty($activate_CAPTCHA_after_failed_attempts) 
-    && !preg_match('/^\d+:\d+:\d+$/', $activate_CAPTCHA_after_failed_attempts))
+    && !preg_match('/^\d+:\d+:\d+(:\d+|)$/', $activate_CAPTCHA_after_failed_attempts))
    {
-      do_err('Lockout plugin is misconfigured: $activate_CAPTCHA_after_failed_attempts must be in the form "n:n:n", where each "n" must be a number', FALSE);
+      do_err('Lockout plugin is misconfigured: $activate_CAPTCHA_after_failed_attempts must be in the form "n:n:n:n", where each "n" must be a number', FALSE);
       return TRUE;
    }
 
@@ -664,6 +664,12 @@ function reset_failed_login_count_do()
 
       setPref($data_dir, 'lockout_plugin_login_failure_information', $remote_addr . '_CAPTCHA_login_failure_times', '');
 
+      // immediately deactivate CAPTCHA validation if configured
+      // 
+      $activate_CAPTCHA_config = explode(':', $activate_CAPTCHA_after_failed_attempts);
+      if (!empty($activate_CAPTCHA_config[3]))
+         setPref($data_dir, 'lockout_plugin_login_failure_information', $remote_addr . '_CAPTCHA_TOO_MANY_FAILED_LOGIN_ATTEMPTS', '');
+
       $prefs_are_cached = FALSE;
       $prefs_cache = FALSE;
       sqsession_unregister('prefs_are_cached');
